==> haskell-crypton-x509-system-1.6.7-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypton-x509-system
version:              1.6.7
visibility:           public
id:                   crypton-x509-system-1.6.7-INNtygljq5oL3NmvDhG5Th
key:                  crypton-x509-system-1.6.7-INNtygljq5oL3NmvDhG5Th
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             Handle per-operating-system X.509 accessors and storage
description:
    System X.509 handling for accessing operating system dependents store and other storage methods

category:             Data
abi:                  11c0a579da6db378becb1eb88686c06c
exposed:              True
exposed-modules:      System.X509 System.X509.MacOS System.X509.Unix
import-dirs:          /usr/lib/ghc-9.2.8/site-local/crypton-x509-system-1.6.7
library-dirs:         /usr/lib/ghc-9.2.8/site-local/crypton-x509-system-1.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-system
hs-libraries:         HScrypton-x509-system-1.6.7-INNtygljq5oL3NmvDhG5Th
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    crypton-x509-1.7.6-54csS6cbMUC7g2sKbnlD4J
    crypton-x509-store-1.6.9-AkzaU0xYwQaJc6BixiSHZz directory-1.3.6.2
    filepath-1.4.2.2 mtl-2.2.2 pem-0.2.4-7Brd6QWgGl5BMOExVgQyBy
    process-1.6.16.0

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-system/html/crypton-x509-system.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-system/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-x509-system-1.6.7-42-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypton-x509-system
version:              1.6.7
visibility:           public
id:                   crypton-x509-system-1.6.7-9ECC8f1Kcr4DTWxpdafbuC
key:                  crypton-x509-system-1.6.7-9ECC8f1Kcr4DTWxpdafbuC
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             Handle per-operating-system X.509 accessors and storage
description:
    System X.509 handling for accessing operating system dependents store and other storage methods

category:             Data
abi:                  adb66c337cddda3707098b6e1fdacadf
exposed:              True
exposed-modules:      System.X509 System.X509.MacOS System.X509.Unix
import-dirs:          /usr/lib/ghc-9.2.8/site-local/crypton-x509-system-1.6.7
library-dirs:         /usr/lib/ghc-9.2.8/site-local/crypton-x509-system-1.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-system
hs-libraries:         HScrypton-x509-system-1.6.7-9ECC8f1Kcr4DTWxpdafbuC
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    crypton-x509-1.7.6-BxdovUSlNoP1M4XPzqsjUN
    crypton-x509-store-1.6.9-IMJoZ4vLRtj4nqf9KbOEzV directory-1.3.6.2
    filepath-1.4.2.2 mtl-2.2.2 pem-0.2.4-FAcuywtMEBuL2NeN5yHYPa
    process-1.6.16.0

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-system/html/crypton-x509-system.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-system/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
